@@ -256,7 +256,7 @@ class ShortComputeTask(steps.LambdaStep):
             "MemorySize": self.memory,
             "Role": self.role_arn,
             "Runtime": self.runtime,
-            "Tags": self._set_tags(project),
+            "Tags": self._set_tags(project, cfn=True),
             "Timeout": self.timeout
         }
         if code_location:
@@ -396,7 +396,10 @@ class ShortComputeTask(steps.LambdaStep):
         os.remove(package_location)
         return { "S3Bucket": artifact_bucket, "S3Key": key }
     
-    def _set_tags(self, project):
-        self.tags['App'] = project
-        return self.tags
+    def _set_tags(self, project, cfn=False):
+        if not cfn:
+            self.tags['App'] = project
+            return self.tags
+        else:
+            return [{ "Key": "App", "Value": project}]
     
\ No newline at end of file
